@@ -19,7 +19,7 @@
 	 *
 	 * @package MantisBT
 	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @copyright Copyright (C) 2002 - 2012  MantisBT Team - mantisbt-dev@lists.sourceforge.net
 	 * @link http://www.mantisbt.org
 	 */
 
@@ -82,6 +82,7 @@
 
 		$f_category_id			= $t_bug->category_id;
 		$f_reproducibility		= $t_bug->reproducibility;
+		$f_eta					= $t_bug->eta;
 		$f_severity				= $t_bug->severity;
 		$f_priority				= $t_bug->priority;
 		$f_summary				= $t_bug->summary;
@@ -106,6 +107,7 @@
 
 		$f_category_id			= gpc_get_int( 'category_id', 0 );
 		$f_reproducibility		= gpc_get_int( 'reproducibility', config_get( 'default_bug_reproducibility' ) );
+		$f_eta					= gpc_get_int( 'eta', config_get( 'default_bug_eta' ) );
 		$f_severity				= gpc_get_int( 'severity', config_get( 'default_bug_severity' ) );
 		$f_priority				= gpc_get_int( 'priority', config_get( 'default_bug_priority' ) );
 		$f_summary				= gpc_get_string( 'summary', '' );
@@ -133,6 +135,7 @@
 
 	$tpl_show_category = in_array( 'category_id', $t_fields );
 	$tpl_show_reproducibility = in_array( 'reproducibility', $t_fields );
+	$tpl_show_eta = in_array( 'eta', $t_fields );
 	$tpl_show_severity = in_array( 'severity', $t_fields );
 	$tpl_show_priority = in_array( 'priority', $t_fields );
 	$tpl_show_steps_to_reproduce = in_array( 'steps_to_reproduce', $t_fields );
@@ -207,7 +210,23 @@
 	</tr>
 <?php
 	}
+	
+	if ( $tpl_show_eta ) {
+?>
 
+	<tr <?php echo helper_alternate_class() ?>>
+		<td class="category">
+			<label for="eta"><?php print_documentation_link( 'eta' ) ?></label>
+		</td>
+		<td>
+			<select <?php echo helper_get_tab_index() ?> id="eta" name="eta">
+				<?php print_enum_string_option_list( 'eta', $f_eta ) ?>
+			</select>
+		</td>
+	</tr>
+<?php
+	}
+	
 	if ( $tpl_show_severity ) {
 ?>
 	<tr <?php echo helper_alternate_class() ?>>
@@ -460,22 +479,36 @@
 		}
 	} # foreach( $t_related_custom_field_ids as $t_id )
 ?>
-<?php if ( $tpl_show_attachments ) { // File Upload (if enabled)
-	$t_max_file_size = (int)min( ini_get_number( 'upload_max_filesize' ), ini_get_number( 'post_max_size' ), config_get( 'max_file_size' ) );
+<?php
+	// File Upload (if enabled)
+	if ( $tpl_show_attachments ) {
+		$t_max_file_size = (int)min( ini_get_number( 'upload_max_filesize' ), ini_get_number( 'post_max_size' ), config_get( 'max_file_size' ) );
+		$t_file_upload_max_num = max( 1, config_get( 'file_upload_max_num' ) );
 ?>
 	<tr <?php echo helper_alternate_class() ?>>
 		<td class="category">
-			<?php echo lang_get( 'upload_file' ) ?>
+			<?php echo lang_get( $t_file_upload_max_num == 1 ? 'upload_file' : 'upload_files' ) ?>
 			<?php echo '<span class="small">(' . lang_get( 'max_file_size' ) . ': ' . number_format( $t_max_file_size/1000 ) . 'k)</span>'?>
 		</td>
 		<td>
 			<input type="hidden" name="max_file_size" value="<?php echo $t_max_file_size ?>" />
-			<input <?php echo helper_get_tab_index() ?> name="file" type="file" size="60" />
+<?php
+		// Display multiple file upload fields
+		for( $i = 0; $i < $t_file_upload_max_num; $i++ ) {
+?>
+			<input id="ufile[]" name="ufile[]" type="file" size="50" />
+<?php
+			if( $t_file_upload_max_num > 1 ) {
+				echo '<br />';
+			}
+		}
+	}
+?>
 		</td>
 	</tr>
-<?php
-	}
 
+
+<?php
 	if ( $tpl_show_view_state ) {
 ?>
 	<tr <?php echo helper_alternate_class() ?>>
@@ -498,7 +531,7 @@
 			<?php echo lang_get( 'relationship_with_parent' ) ?>
 		</td>
 		<td>
-			<?php relationship_list_box( /* none */ -2, "rel_type", false, true ) ?>
+			<?php relationship_list_box( config_get( 'default_bug_relationship_clone' ), "rel_type", false, true ) ?>
 			<?php echo '<b>' . lang_get( 'bug' ) . ' ' . bug_format_id( $f_master_bug_id ) . '</b>' ?>
 		</td>
 	</tr>
