@@ -17,7 +17,7 @@
 	/**
 	 * @package MantisBT
 	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @copyright Copyright (C) 2002 - 2012  MantisBT Team - mantisbt-dev@lists.sourceforge.net
 	 * @link http://www.mantisbt.org
 	 */
 	 /**
@@ -348,7 +348,7 @@
 	<br />
 	<form method="get" action="manage_user_edit_page.php">
 	<?php # CSRF protection not required here - form does not result in modifications ?>
-		<?php echo lang_get( 'username' ) ?>
+		<?php echo lang_get( 'search' ) ?>
 		<input type="text" name="username" value="" />
 		<input type="submit" class="button" value="<?php echo lang_get( 'manage_user' ) ?>" />
 	</form>
